ADA Graphical Interface Tutorial — ADA 1.0.3 documentation

Skip to main content
`Ctrl`+`K`

# ADA Graphical Interface Tutorial

Welcome to the ADA Graphical Interface Tutorial!

This tutorial is divided into three main sections:

- Analysis walkthrough

- Presets and pipeline

- Settings and help

Please select the desired section from the contents below.

- Analysis walkthrough
  - Step 1: Input file(s)
  - Step 2: Analysis
  - Step 3: Output directory
  - Step 4: Running analysis
  - Step 5: Results browser
- Presets and pipeline
  - Presets
  - Pipeline
- Settings and help
  - Themes
  - Data formats
  - File selection dialogs
  - Help

For a detailed description of the algorithms and estimators used in the ADA GUI, please refer to the accompanying article: ….